
# Slot: prefixes


prefix / URI definitions to be added to the context beyond those fetched from prefixcommons in id prefixes

URI: [linkml:prefixes](https://w3id.org/linkml/prefixes)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [Prefix](Prefix.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
